=====
Tasks
=====

Screen
------

.. autosummary::
    :toctree: api/
    :template: _templates/class_task_template.rst

    prismstudio.screen


Factor Backtest
---------------

.. autosummary::
    :toctree: api/
    :template: _templates/class_task_template.rst

    prismstudio.factor_backtest


Export Data
-----------

.. autosummary::
    :toctree: api/
    :template: _templates/class_task_template.rst

    prismstudio.export_data
